Summary:       SyncML client for evolution
Name:          syncevolution
Version:       1.2
Release:       2%{?dist}
Epoch:         1
License:       LGPLv2+
Group:         Applications/Productivity
URL:           http://syncevolution.org/
Source:        http://downloads.syncevolution.org/%{name}/sources/%{name}-%{version}.tar.gz
# link statically against internal libgdbus to avoid crashing
# basically re-apply upstream ec7eb74366a9d1b2d5390c75a8ab2716d579e0cc
# which was reverted (prematurely) - AdamW 2011/03
# https://bugzilla.redhat.com/show_bug.cgi?id=640750
Patch1:	       syncevolution-1.1.1-gdbus_static.patch
Patch2:        syncevolution-1.99.7-fixbuild.patch

BuildRequires: bluez-libs-devel
BuildRequires: boost-devel
BuildRequires: cppunit-devel
BuildRequires: evolution-data-server-devel
BuildRequires: expat-devel
BuildRequires: glib2-devel
BuildRequires: gnome-keyring-devel
BuildRequires: gtk2-devel
BuildRequires: libcurl-devel
BuildRequires: libical-devel
BuildRequires: libmx-devel
BuildRequires: libnotify-devel
BuildRequires: libsoup-devel
BuildRequires: pcre-devel
BuildRequires: python-docutils
BuildRequires: unique-devel
%ifnarch s390 s390x
BuildRequires: openobex-devel
%endif

BuildRequires: desktop-file-utils
BuildRequires: intltool
BuildRequires: gettext
BuildRequires: libtool

Requires: python-twisted-web

%description
syncevolution is designed to provide a SyncML client that can
connect to and sync with various SyncML-based servers

%package libs
Summary: Library package for %{name}
Group: System Environment/Libraries

%description libs
Libraries for %{name}.

%package devel
Summary: Development package for %{name}
Group: Development/Libraries
Requires: %{name} = %{epoch}:%{version}-%{release}
Requires: pkgconfig

%description devel
Files for development with %{name}.

%package gtk
Summary: GTK+ GUI for %{name}
Group: Applications/Productivity
Requires: %{name} = %{epoch}:%{version}-%{release}

%description gtk
GTK+ GUI for use with %{name}.

%package meego
Summary: MeeGo GUI for %{name}
Group: Applications/Productivity
Requires: %{name} = %{epoch}:%{version}-%{release}
Obsoletes: syncevolution-moblin < 1:1.1
Provides: %{name}-moblin = %{version}

%description meego
MeeGo GUI for use with %{name}.

%package perl
Summary: Perl utils for %{name}
Group: Development/Libraries
Requires: %{name} = %{epoch}:%{version}-%{release}

%description perl
Perl utils for use with %{name}.

%prep
%setup -q
%patch1 -p1 -b .gdbus
%patch2 -p1 -b .synthesis

# use the ac macros in Makefile.am
sed -i '/^ACLOCAL_AMFLAGS/{ /m4-repo/!s/$/ -I m4-repo/ }' Makefile*.am

%build
intltoolize --automake --copy --force
autoreconf -fiv
(cd src/synthesis && autoreconf -fi)

%configure --enable-libsoup --enable-dbus-service --enable-shared \
    --with-expat=system --disable-static --enable-gui=all \
%ifnarch s390 s390x
    --enable-bluetooth
%else
    --disable-bluetooth
%endif
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g
	s|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags} V=1
find . -type d -perm 02755 -exec chmod 0755 '{}' \;

%install
make install DESTDIR=%{buildroot} docdir=%{_docdir}
rm -rf %{buildroot}%{_datadir}/doc

#Remove libtool archives
find %{buildroot} -name '*.la' -exec rm -f {} ';'

%find_lang %{name}

# fix the in the desktop files
sed -i 's/sync-ui/sync-ui-gtk/' %{buildroot}/%{_datadir}/applications/sync-gtk.desktop
sed -i 's/sync-ui/sync-ui-moblin/' %{buildroot}/%{_datadir}/applications/sync-moblin.desktop
# sed -i 's#Categories=Office;PDA;GTK#Categories=Office;PDA;GTK;#' %{buildroot}/%{_datadir}/applications/sync-gtk.desktop

desktop-file-validate %{buildroot}/%{_datadir}/applications/sync-gtk.desktop
desktop-file-validate %{buildroot}/%{_datadir}/applications/sync-moblin.desktop

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS NEWS README HACKING README.html README.rst
%{_sysconfdir}/xdg/autostart/syncevo-dbus-server.desktop
%{_bindir}/syncevolution
%{_bindir}/syncevo-http-server
%{_bindir}/syncevo-phone-config
%{_bindir}/syncevo-webdav-lookup
%{_libexecdir}/syncevo-dbus-server
%{_libexecdir}/syncevo-dbus-server-startup.sh
%{_datadir}/syncevolution
%{_datadir}/dbus-1/services/org.syncevolution.service
%{_datadir}/man/man1/syncevolution.1.gz
%{_datadir}/icons/hicolor/48x48/apps/sync.png
%exclude %{_datadir}/syncevolution/xml/*.pl

%files libs
%defattr(-,root,root,-)
%doc COPYING LICENSE.LGPL-21 LICENSE.txt
%{_libdir}/*so.0*
%dir %{_libdir}/syncevolution
%{_libdir}/syncevolution/backends

%files devel
%defattr(-,root,root,-)
%{_includedir}/syncevo
%{_includedir}/syncevo-dbus
%{_includedir}/synthesis
%{_libdir}/pkgconfig/s*.pc
%{_libdir}/*.so
%{_libdir}/*.a

%files gtk
%defattr(-,root,root,-)
%{_bindir}/sync-ui-gtk
%{_datadir}/applications/sync-gtk.desktop

%files meego
%defattr(-,root,root,-)
%{_bindir}/sync-ui-moblin
%{_datadir}/applications/sync-moblin.desktop

%files perl
%defattr(-,root,root,-)
%{_bindir}/synccompare
%{_datadir}/syncevolution/xml/*.pl

%changelog
* Mon Oct 17 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.2-1
- 1.2 stable release

* Thu Oct 13 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1.99.7-2
- Own syncevolution directory - fixes RHBZ 744929

* Fri Sep 16 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1.99.7-1
- update to 1.1.99.7

* Tue Aug 30 2011 Milan Crha <mcrha@redhat.com> - 1:1.1.99.6-3
- Rebuild against newer evolution-data-server (once again)

* Mon Aug 29 2011 Milan Crha <mcrha@redhat.com> - 1:1.1.99.6-2
- Rebuild against newer evolution-data-server

* Thu Aug 18 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1.99.6-1
- update to 1.1.99.6
- Add static libs to devel as they are needed for dev :-/ Fixes # 715131

* Tue Aug 16 2011 Milan Crha <mcrha@redhat.com> - 1:1.1.99.5a-3
- Rebuild against newer evolution-data-server

* Sun Jul 23 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1.99.5a-2
- Rebuild against newer evolution-data-server

* Fri Jul 15 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1.99.5a-1
- Update to 1.1.99.5a devel release

* Thu Jun 16 2011 Milan Crha <mcrha@redhat.com> 1:1.1.99.4-3
- Rebuild against newer evolution-data-server

* Fri May 20 2011 Kalev Lember <kalev@smartlink.ee> - 1:1.1.99.4-2
- Rebuilt for libcamel soname bump

* Thu Apr 28 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1.99.4-1
- Update to 1.1.99.4 devel release

* Thu Mar 3 2011 Adam Williamson <awilliam@redhat.com> - 1:1.1.1-6
- build the private libgdbus statically again for now to avoid crasher

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Feb  3 2011 Dan Horák <dan[at]danny.cz> 1:1.1.1-4
- fix build on s390 where size_t != unsigned int

* Tue Feb  1 2011 Dan Horák <dan[at]danny.cz> 1:1.1.1-3
- fix build with gcc 4.6
- disable bluetooth on s390(x)

* Wed Jan 12 2011 Milan Crha <mcrha@redhat.com> 1:1.1.1-2
- Rebuild against newer evolution-data-server

* Sun Dec 26 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1.1-1
- Update to 1.1.1 stable release

* Tue Dec 14 2010 Adam Williamson <awilliam@redhat.com> - 1:1.1-4
- really fix the obsolete

* Sun Dec  5 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1-3
- Update deps and other spec bits

* Wed Nov 24 2010 Adam Williamson <awilliam@redhat.com> - 1:1.1-2
- add libnotify07 patch to build against libnotify 0.7

* Tue Oct 26 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.1-1
- Update to 1.1 stable release

* Sat Oct 16 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.99.7-2
- Bump build, rename moblin subpackage to meego

* Fri Oct  1 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.99.7-1
- Update to 1.0.99.7 devel release

* Wed Sep 29 2010 jkeating - 1:1.0.99.6-3
- Rebuilt for gcc bug 634757

* Tue Sep 21 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.99.6-2
- Enable bluetooth support. Fixes RHBZ # 612000

* Tue Sep 14 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.99.6-1
- Update to 1.0.99.6 devel release

ntteo centra Sat Aug  7 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.1-5
- fix the binary name in the desktop file

* Fri Jul 23 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.1-4
- And twice more with feeling

* Fri Jul 23 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.1-3
- And once more with feeling

* Fri Jul 23 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.1-2
- Add patch to fix linking against libnotify and gtk-2.0 (thanks hadess)

* Fri Jul 23 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0.1-1
- Update to new 1.0.1 stable release

* Mon Jul 12 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0-2
- Move license to libs

* Sun Jun 20 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1:1.0-1
- Add epoch to fix upgrades

* Sat Jun 19 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1.0-1
- Update to new 1.0.0 stable release, split out libs

* Wed May 26 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1.0beta3-2
- Bump build for new evolution

* Tue May  4 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1.0beta3-2
- Fix file moves and additions

* Wed Apr 21 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1.0beta3-1
- Update to 1.0.0 beta 3

* Wed Jan 27 2010 Peter Robinson <pbrobinson@fedoraproject.org> - 1.0beta1-1
- Update to 1.0.0 beta 1

* Thu Dec  3 2009 Peter Robinson <pbrobinson@fedoraproject.org> - 0.9.2+1.0alpha1-1
- Update to 1.0.0 alpha 1

* Tue Nov 17 2009 Peter Robinson <pbrobinson@fedoraproject.org> - 0.9-3
- Spec updates, split perl utils into sub-package

* Fri Oct 16 2009 Peter Robinson <pbrobinson@fedoraproject.org> - 0.9-2
- Enable the gtk and moblin guis

* Fri Sep 25 2009 Matěj Cepl <mcepl@redhat.com> - 0.9-1
- New upstream release.

* Wed Aug  5 2009 Matěj Cepl <mcepl@redhat.com> - 0.8.1+0.9+beta3+20090723-1.0.3
- missing BuildRequires

* Wed Aug  5 2009 Stepan Kasal <skasal@redhat.com> - 0.8.1+0.9+beta3+20090723-1.0.2
- fixing autoconfigury; now it fails in a later stage of build ;-)

* Wed Aug  5 2009 Matěj Cepl <mcepl@redhat.com> - 0.8.1+0.9+beta3+20090723-1.0.1
- fixing rpath, currently FTBFS!!!

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1a-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar 23 2009 Matej Cepl <mcepl@redhat.com> 0.8.1a-1
- New upstream release.
- make a fix for one #elif which should be #else

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Oct  6 2008 Alex Lancaster <alexlan[AT] fedoraproject.org> - 0.7-4
- Rebuild against new libcppunit to fix broken deps

* Fri Aug 01 2008 Matěj Cepl <mcepl@redhat.com> 0.7-3
- Bump the release to fix broken update path for Rawhide

* Fri Feb 15 2008 Matěj Cepl <mcepl@redhat.com> 0.7-2
- Add #include <memory> to syncevolution.cpp according
  to https://sourceforge.net/tracker/\
  ?func=detail&amp;atid=764733&amp;aid=1893582&amp;group_id=146288

* Wed Feb 13 2008 Matěj Cepl <mcepl@redhat.com> 0.7-1
- New upstream version.

* Mon Oct 15 2007 matej <mcepl@redhat.com> 0.6-2
- updated SPEC to make the package approved for the Fedora
  review process.

* Sun Oct 12 2007 Matěj Cepl <mcepl@redhat.com> 0.6-1
- Fixing .spec -- use make install and others
- Install also configuration templates to %%docs

* Sun Sep 30 2007 Matěj Cepl <mcepl@redhat.com> 0.6-0
- Experimental build from upstream source.

* Tue Jan 16 2007 Richard Monk <rmonk@redhat.com> 0.5-1
- Inital packaging
